@@ -98,6 +98,16 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
             self._mod = SubmissionModeration(self)
         return self._mod
 
+    @property
+    def shortlink(self):
+        """Return a shortlink to the submission.
+
+        For example http://redd.it/eorhm is a shortlink for
+        https://www.reddit.com/r/announcements/comments/eorhm/reddit_30_less_typing/.
+
+        """
+        return urljoin(self._reddit.config.short_url, self.id)
+
     def __init__(self, reddit, id=None,  # pylint: disable=redefined-builtin
                  url=None, _data=None):
         """Initialize a Submission instance.
@@ -158,6 +168,20 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
     def _info_path(self):
         return API_PATH['submission'].format(id=self.id)
 
+    def mark_visited(self):
+        """Mark submission as visited.
+
+        Example usage:
+
+        .. code:: python
+
+           submission = reddit.submission(id='5or86n')
+           submission.mark_visited()
+
+        """
+        data = {'links': self.fullname}
+        self._reddit.post(API_PATH['store_visits'], data=data)
+
     def hide(self, other_submissions=None):
         """Hide Submission.
 
@@ -165,20 +189,19 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
             hide this list of :class:`.Submission` instances
             as part of a single request (default: None).
 
+        Example usage:
+
+        .. code:: python
+
+           submission = reddit.submission(id='5or86n')
+           submission.hide()
+
+        See also :meth:`~.unhide`
+
         """
         for submissions in self._chunk(other_submissions, 50):
             self._reddit.post(API_PATH['hide'], data={'id': submissions})
 
-    @property
-    def shortlink(self):
-        """Return a shortlink to the submission.
-
-        For example http://redd.it/eorhm is a shortlink for
-        https://www.reddit.com/r/announcements/comments/eorhm/reddit_30_less_typing/.
-
-        """
-        return urljoin(self._reddit.config.short_url, self.id)
-
     def unhide(self, other_submissions=None):
         """Unhide Submission.
 
@@ -186,6 +209,15 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
             unhide this list of :class:`.Submission` instances
             as part of a single request (default: None).
 
+        Example usage:
+
+        .. code:: python
+
+           submission = reddit.submission(id='5or86n')
+           submission.unhide()
+
+        See also :meth:`~.hide`
+
         """
         for submissions in self._chunk(other_submissions, 50):
             self._reddit.post(API_PATH['unhide'], data={'id': submissions})
@@ -202,6 +234,17 @@ class Submission(RedditBase, SubmissionListingMixin, UserContentMixin):
             (default: True).
         :returns: A :class:`~.Submission` object for the newly created
             submission.
+
+        Example usage:
+
+        .. code:: python
+
+           submission = reddit.submission(id='5or86n')
+           cross_post = submission.crosspost(subreddit="learnprogramming",
+                                             send_replies=False)
+
+        See also :meth:`~.hide`
+
         """
         if title is None:
             title = self.title
@@ -270,7 +313,16 @@ class SubmissionFlair(object):
 
 
 class SubmissionModeration(ThingModerationMixin):
-    """Provide a set of functions pertaining to Submission moderation."""
+    """Provide a set of functions pertaining to Submission moderation.
+
+    Example usage:
+
+    .. code:: python
+
+       submission = reddit.submission(id="8dmv8z")
+       submission.mod.approve()
+
+    """
 
     def __init__(self, submission):
         """Create a SubmissionModeration instance.
@@ -294,6 +346,13 @@ class SubmissionModeration(ThingModerationMixin):
           * Scores accessed through the API (mobile apps, bots) will be
             obscured to "1" for non-moderators.
 
+        Example usage:
+
+        .. code:: python
+
+           submission = reddit.submission(id='5or86n')
+           submission.mod.contest_mode(state=True)
+
         """
         self.thing._reddit.post(API_PATH['contest_mode'], data={
             'id': self.thing.fullname, 'state': state})
@@ -309,10 +368,11 @@ class SubmissionModeration(ThingModerationMixin):
         This method can only be used by an authenticated user who is a
         moderator of the Submission's Subreddit.
 
-        Example:
+        Example usage:
 
         .. code:: python
 
+           submission = reddit.submission(id='5or86n')
            submission.mod.flair(text='PRAW', css_class='bot')
 
         """
@@ -322,7 +382,18 @@ class SubmissionModeration(ThingModerationMixin):
         self.thing._reddit.post(url, data=data)
 
     def lock(self):
-        """Lock the submission."""
+        """Lock the submission.
+
+        Example usage:
+
+        .. code:: python
+
+           submission = reddit.submission(id='5or86n')
+           submission.mod.lock()
+
+        See also :meth:`~.unlock`
+
+        """
         self.thing._reddit.post(API_PATH['lock'],
                                 data={'id': self.thing.fullname})
 
@@ -332,13 +403,15 @@ class SubmissionModeration(ThingModerationMixin):
         This method can be used both by the submission author and moderators of
         the subreddit that the submission belongs to.
 
-        Example:
+        Example usage:
 
         .. code:: python
 
-            submission = reddit.subreddit('test').submit('nsfw test',
-                                                         selftext='nsfw')
-            submission.mod.nsfw()
+           submission = reddit.subreddit('test').submit('nsfw test',
+                                                        selftext='nsfw')
+           submission.mod.nsfw()
+
+        See also :meth:`~.sfw`
 
         """
         self.thing._reddit.post(API_PATH['marknsfw'],
@@ -350,12 +423,14 @@ class SubmissionModeration(ThingModerationMixin):
         This method can be used both by the submission author and moderators of
         the subreddit that the submission belongs to.
 
-        Example:
+        Example usage:
 
         .. code:: python
 
-            submission = reddit.submission(id='5or86n')
-            submission.mod.sfw()
+           submission = reddit.submission(id='5or86n')
+           submission.mod.sfw()
+
+        See also :meth:`~.nsfw`
 
         """
         self.thing._reddit.post(API_PATH['unmarknsfw'],
@@ -367,12 +442,14 @@ class SubmissionModeration(ThingModerationMixin):
         This method can be used both by the submission author and moderators of
         the subreddit that the submission belongs to.
 
-        Example:
+        Example usage:
 
         .. code:: python
 
-            submission = reddit.submission(id='5or86n')
-            submission.mod.spoiler()
+           submission = reddit.submission(id='5or86n')
+           submission.mod.spoiler()
+
+        See also :meth:`~.unspoiler`
 
         """
         self.thing._reddit.post(API_PATH['spoiler'],
@@ -394,6 +471,7 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code:: python
 
+           submission = reddit.submission(id='5or86n')
            submission.mod.sticky()
 
         """
@@ -414,7 +492,18 @@ class SubmissionModeration(ThingModerationMixin):
             'id': self.thing.fullname, 'sort': sort})
 
     def unlock(self):
-        """Unlock the submission."""
+        """Unlock the submission.
+
+        Example:
+
+        .. code:: python
+
+           submission = reddit.submission(id='5or86n')
+           submission.mod.unlock()
+
+        See also :meth:`~.lock`
+
+        """
         self.thing._reddit.post(API_PATH['unlock'],
                                 data={'id': self.thing.fullname})
 
@@ -428,9 +517,11 @@ class SubmissionModeration(ThingModerationMixin):
 
         .. code:: python
 
-            submission = reddit.subreddit('test').submit('not spoiler',
-                                                         selftext='spoiler')
-            submission.mod.unspoiler()
+           submission = reddit.subreddit('test').submit('not spoiler',
+                                                        selftext='spoiler')
+           submission.mod.unspoiler()
+
+        See also :meth:`~.spoiler`
 
         """
         self.thing._reddit.post(API_PATH['unspoiler'],
